/*
** device_dialog.c
** 
** Made by (Arne Caspari)
** Login   <arne@arne-laptop>
** 
** Started on  Wed Nov 15 07:19:16 2006 Arne Caspari
*/

#include "device_dialog.h"

#include <gtk/gtk.h>
#include <unicapgtk.h>

#include <string.h>

static void device_change_cb( UnicapgtkDeviceSelection *selecion, gchar *device_id, device_dialog_t *dlg )
{
   unicap_handle_t handle;
   unicap_device_t device;
   
   unicap_void_device( &device );
   strcpy( device.identifier, device_id );
   unicap_enumerate_devices( &device, &device, 0 );
   
   if( SUCCESS( unicap_open( &handle, &device ) ) )
   {
      unicapgtk_video_format_selection_set_handle( UNICAPGTK_VIDEO_FORMAT_SELECTION( dlg->format_selection ), 
						   handle );
   }
}

static void format_change_cb( UnicapgtkVideoFormatSelection *sel, unicap_format_t *format, device_dialog_t *dlg )
{
   unicap_handle_t handle;
   handle = unicapgtk_video_format_selection_get_handle( sel );
   if( handle )
   {
      unicap_set_format( handle, format );
      printf( "Set format %s %dx%d\n", format->identifier, format->size.width, format->size.height );
      unicap_get_format( handle, format );
      printf( "Get format %s %dx%d\n", format->identifier, format->size.width, format->size.height );

   }
   else
   {
      printf( "!handle\n" );
   }
   
}

static void delete_cb( GtkWidget *window, GdkEvent *event, device_dialog_t *dlg )
{
   dlg->delete = TRUE;
}

static void ok_cb( GtkWidget *button, device_dialog_t *dlg )
{
   unicap_handle_t handle;
   handle = unicapgtk_video_format_selection_get_handle( UNICAPGTK_VIDEO_FORMAT_SELECTION( dlg->format_selection ) );
   dlg->handle = handle;
}


device_dialog_t *create_device_dialog( gboolean include_fmt_selection, 
				       unicap_device_t *default_device )
{
   GtkWidget *window;
   GtkWidget *vbox;
   GtkWidget *label;
   GtkWidget *device_selection;
   GtkWidget *format_selection;
   GtkWidget *table;
   GtkWidget *bbox;
   device_dialog_t *dlg;
   
   dlg = g_malloc( sizeof( device_dialog_t ) );
   memset( dlg, 0x0, sizeof( device_dialog_t ) );
   
   window = gtk_window_new( GTK_WINDOW_TOPLEVEL );
   gtk_window_set_title( GTK_WINDOW( window ), "Select Device" );
   dlg->window = window;
   vbox = gtk_vbox_new( FALSE, FALSE );
   gtk_container_add( GTK_CONTAINER( window ), vbox );
   table = gtk_table_new( 2, 2, FALSE );
   gtk_box_pack_start( GTK_BOX( vbox ), table, FALSE, FALSE, 0 );
   label = gtk_label_new( NULL );
   gtk_label_set_markup( GTK_LABEL( label ), "<b>Device:</b>" );
   gtk_table_attach_defaults( GTK_TABLE( table ), label, 0, 1, 0, 1 );
   device_selection = unicapgtk_device_selection_new( FALSE );
   unicapgtk_device_selection_rescan( UNICAPGTK_DEVICE_SELECTION( device_selection ) );
   gtk_table_attach_defaults( GTK_TABLE( table ), device_selection, 1, 2, 0, 1 );

   label = gtk_label_new( NULL );
   gtk_label_set_markup( GTK_LABEL( label ), "<b>Video Format:</b>" );
   gtk_table_attach_defaults( GTK_TABLE( table ), label, 0, 1, 1, 2 );
   format_selection = unicapgtk_video_format_selection_new( FALSE );
   dlg->format_selection = format_selection;
   gtk_table_attach_defaults( GTK_TABLE( table ), format_selection, 1, 2, 1, 2 );

   gtk_table_set_row_spacings( GTK_TABLE( table ), 5 );
   gtk_table_set_col_spacings( GTK_TABLE( table ), 5 );

   bbox = gtk_hbutton_box_new( );
   gtk_box_pack_start( GTK_BOX( vbox ), bbox, FALSE, FALSE, 0 );
   
   dlg->ok_button = gtk_button_new_from_stock( GTK_STOCK_OK );
   gtk_container_add( GTK_CONTAINER( bbox ), dlg->ok_button );
   gtk_widget_grab_focus( dlg->ok_button );

   g_signal_connect( G_OBJECT( device_selection ), "unicapgtk_device_selection_changed", (GCallback)device_change_cb, dlg );
   g_signal_connect( G_OBJECT( format_selection ), "unicapgtk_video_format_changed", (GCallback)format_change_cb, dlg );
   g_signal_connect( G_OBJECT( window ), "delete-event", (GCallback)delete_cb, dlg );
   g_signal_connect( G_OBJECT( dlg->ok_button ), "clicked", (GCallback)ok_cb, dlg );
   unicapgtk_device_selection_set_device( UNICAPGTK_DEVICE_SELECTION( device_selection ), default_device );

   return dlg;
}

unicap_handle_t device_dialog_run( device_dialog_t *dlg )
{
   gtk_widget_show_all( dlg->window );
   gtk_window_present( GTK_WINDOW( dlg->window ) );
   while( ( !dlg->handle ) && ( !dlg->delete ) )
   {
      gtk_main_iteration();
   }

   return dlg->handle;
}

void device_dialog_destroy( device_dialog_t *dlg )
{
      gtk_widget_destroy( dlg->window );      
}
