/*
** settings_dialog.c
** 
** Made by (Arne Caspari)
** Login   <arne@arne-laptop>
** 
** Started on  Fri Feb 16 17:13:05 2007 Arne Caspari
** Last update Mon Feb 19 22:16:40 2007 Arne Caspari
*/

#include <gtk/gtk.h>
#include <gconf/gconf-client.h>


#include "settings_dialog.h"
#include "ucview.h"


static void settings_dialog_class_init          (SettingsDialogClass *klass);
static void settings_dialog_init                (SettingsDialog      *dlg);
static void settings_dialog_set_property        ( GObject       *object, 
						  guint          property_id, 
						  const GValue  *value, 
						  GParamSpec    *pspec );
static void settings_dialog_get_property        ( GObject       *object, 
						  guint          property_id, 
						  GValue        *value, 
						  GParamSpec    *pspec );

G_DEFINE_TYPE( SettingsDialog, settings_dialog, GTK_TYPE_WINDOW );


enum
{
   PROP_0 = 0,
   PROP_VIDEO_FILENAME,
   PROP_STILL_IMAGE_FILENAME,
};

static void file_activated_cb( GtkFileChooser *chooser, gchar *gconf_key )
{
   GConfClient *client;
   gchar *gconf_path;
   
   client = g_object_get_data( G_OBJECT( chooser ), "client" );
   g_assert( client );

   gconf_path = g_strconcat( UCVIEW_GCONF_DIR, "/", gconf_key, NULL );

   gconf_client_set_string( client, gconf_path, gtk_file_chooser_get_filename( chooser ), NULL );

   g_free( gconf_path );
}



static void settings_dialog_class_init( SettingsDialogClass *klass )
{
   GObjectClass *object_class = G_OBJECT_CLASS( klass );
/*    GtkObjectClass *gtk_object_class = GTK_OBJECT_CLASS( klass ); */

   object_class->set_property = settings_dialog_set_property;
   object_class->get_property = settings_dialog_get_property;

   g_object_class_install_property (object_class,
				    PROP_VIDEO_FILENAME,
				    g_param_spec_string ("video-filename",
							 NULL, NULL,
							 FALSE,
							 G_PARAM_READWRITE));
   g_object_class_install_property (object_class,
				    PROP_STILL_IMAGE_FILENAME,
				    g_param_spec_string ("still-image-filename",
							 NULL, NULL,
							 FALSE,
							 G_PARAM_READWRITE));
   

}

static void settings_dialog_init( SettingsDialog *dlg )
{
   GtkWidget *vbox;
   GtkWidget *hbox;
   GtkWidget *label;
   GtkWidget *file_button;
   gchar *path;

   dlg->client = gconf_client_get_default();
   gconf_client_add_dir( dlg->client, UCVIEW_GCONF_DIR, GCONF_CLIENT_PRELOAD_NONE, NULL );   

   gtk_window_set_type_hint( GTK_WINDOW( dlg ), GDK_WINDOW_TYPE_HINT_DIALOG );
   gtk_container_set_border_width( GTK_CONTAINER( dlg ), 12 );
   
   vbox = gtk_vbox_new( FALSE, 12 );
   gtk_container_add( GTK_CONTAINER( dlg ), vbox );
   
   hbox = gtk_hbox_new( FALSE, 12 );
   gtk_box_pack_start( GTK_BOX( vbox ), hbox, TRUE, TRUE, 0 );

   label = gtk_label_new( "Video File Path: " );
   gtk_box_pack_start( GTK_BOX( hbox ), label, FALSE, FALSE, 0 );
   file_button = gtk_file_chooser_button_new( "Video File Path", GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER );
   gtk_box_pack_start( GTK_BOX( hbox ), file_button, TRUE, TRUE, 0 );
   dlg->video_file_button = file_button;
   if( ( path = gconf_client_get_string( dlg->client, UCVIEW_GCONF_DIR "/video_file_path", NULL ) ) )
   {
      gtk_file_chooser_set_filename( GTK_FILE_CHOOSER( file_button ), path );
   }
   
   hbox = gtk_hbox_new( FALSE, 12 );
   gtk_box_pack_start( GTK_BOX( vbox ), hbox, TRUE, TRUE, 0 );
   g_object_set_data( G_OBJECT( file_button ), "client", dlg->client );
   g_signal_connect( G_OBJECT( file_button ), "selection-changed", G_CALLBACK( file_activated_cb ), "video_file_path" );

   label = gtk_label_new( "Still Image File Path: " );
   gtk_box_pack_start( GTK_BOX( hbox ), label, FALSE, FALSE, 0 );
   file_button = gtk_file_chooser_button_new( "Still Image File Path", GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER );
   gtk_box_pack_start( GTK_BOX( hbox ), file_button, TRUE, TRUE, 0 );
   dlg->still_image_file_button = file_button;
   if( ( path = gconf_client_get_string( dlg->client, UCVIEW_GCONF_DIR "/still_image_file_path", NULL ) ) )
   {
      gtk_file_chooser_set_filename( GTK_FILE_CHOOSER( file_button ), path );
   }
   g_object_set_data( G_OBJECT( file_button ), "client", dlg->client );
   g_signal_connect( G_OBJECT( file_button ), "selection-changed", G_CALLBACK( file_activated_cb ), "still_image_file_path" );
   
   gtk_widget_show_all( vbox );
}

static void settings_dialog_set_property( GObject *object, 
					  guint property_id, 
					  const GValue *value, 
					  GParamSpec *pspec )
{
   SettingsDialog *dlg = SETTINGS_DIALOG( object );

   switch( property_id )
   {
      case PROP_VIDEO_FILENAME:
	 gtk_file_chooser_set_filename( GTK_FILE_CHOOSER( dlg->video_file_button ), g_value_get_string( value ) );
	 break;

      case PROP_STILL_IMAGE_FILENAME:
	 gtk_file_chooser_set_filename( GTK_FILE_CHOOSER( dlg->still_image_file_button ), g_value_get_string( value ) );
	 break;	 

      default:
	 G_OBJECT_WARN_INVALID_PROPERTY_ID( object, property_id, pspec );
	 break;
   }
}

static void settings_dialog_get_property( GObject *object, 
					  guint property_id, 
					  GValue *value, 
					  GParamSpec *pspec )
{
   SettingsDialog *dlg = SETTINGS_DIALOG( object );

   switch( property_id )
   {
      case PROP_VIDEO_FILENAME:
	 g_value_set_string( value, gtk_file_chooser_get_filename( GTK_FILE_CHOOSER( dlg->video_file_button ) ) );
         break;

      case PROP_STILL_IMAGE_FILENAME:
	 g_value_set_string( value, gtk_file_chooser_get_filename( GTK_FILE_CHOOSER( dlg->still_image_file_button ) ) );
	 break;

      default:
	 G_OBJECT_WARN_INVALID_PROPERTY_ID( object, property_id, pspec );
	 break;
   }
}

GtkWidget *settings_dialog_new( void )
{
   SettingsDialog *dlg;
   
   dlg = g_object_new( SETTINGS_DIALOG_TYPE, NULL );
   
   return GTK_WIDGET( dlg );
}

